@@ -1,6 +1,22 @@
 # coding: utf-8
 from pymongo import MongoClient
 
+"""
+use admin
+db.createUser( 
+  { 
+    user: "XXX", 
+    pwd: "XXXXXXX", 
+    roles: [ { role: "root", db: "admin" } ] 
+  } )
+再开启验证(mongod.conf)
+
+
+删除用户：
+use XXXX
+db.dropUser('XXXXX')
+"""
+
 
 class BaseMongoDB(object):
     """
@@ -11,9 +27,9 @@ class BaseMongoDB(object):
         self.name = name
         # self.client = MongoClient(host, port, **kwargs)
         # self.client.admin.authenticate(config.database.username, config.database.password)
-        if 'password' in kwargs and 'user' in kwargs:
+        if 'password' in kwargs and 'user' in kwargs and 'source' in kwargs:
             mongo_url = 'mongodb://{0}:{1}@{2}:{3}/?authSource={4}&authMechanism=SCRAM-SHA-1'.format(
-                kwargs['user'], kwargs['password'], host, port, db)
+                kwargs['user'], kwargs['password'], host, port, kwargs['source'])
         else:
             mongo_url = 'mongodb://{0}:{1}/?authSource={2}&authMechanism=SCRAM-SHA-1'.format(host, port, db)
         # mongo_url = parse.quote(mongo_url)
